summaryrefslogtreecommitdiff
path: root/gcc/cp/parse.c
diff options
context:
space:
mode:
Diffstat (limited to 'gcc/cp/parse.c')
-rw-r--r--gcc/cp/parse.c13
1 files changed, 6 insertions, 7 deletions
diff --git a/gcc/cp/parse.c b/gcc/cp/parse.c
index 44f7ff2fdc5..306bd16e05e 100644
--- a/gcc/cp/parse.c
+++ b/gcc/cp/parse.c
@@ -1,7 +1,6 @@
/* A Bison parser, made from parse.y
- by GNU Bison version 1.27
- */
+ by GNU Bison version 1.28 */
#define YYBISON 1 /* Identify Bison output. */
@@ -4031,8 +4030,8 @@ static const short yycheck[] = { 4,
78, 79, 80, 81, 82, 83, 84, 85
};
/* -*-C-*- Note some compilers choke on comments on `#line' lines. */
#line 3 "/usr/share/bison.simple"
/* This file comes from bison-1.27. */
/* Skeleton output parser for bison,
Copyright (C) 1984, 1989, 1990 Free Software Foundation, Inc.
@@ -4245,7 +4244,7 @@ __yy_memcpy (char *to, char *from, unsigned int count)
#endif
#endif
-#line 216 "/usr/share/bison.simple"
+#line 217 "/usr/lib/bison.simple"
/* The user can define YYPARSE_PARAM as the name of an argument to be passed
into yyparse. The argument should have type void *.
@@ -6543,7 +6542,7 @@ case 480:
/* struct B: public A; is not accepted by the standard grammar. */
if (CLASS_TYPE_P (yyval.ftype.t)
&& TYPE_BINFO_BASETYPES (yyval.ftype.t)
- && !TYPE_SIZE (yyval.ftype.t)
+ && !COMPLETE_TYPE_P (yyval.ftype.t)
&& ! TYPE_BEING_DEFINED (yyval.ftype.t))
cp_error ("base clause without member specification for `%#T'",
yyval.ftype.t);
@@ -8230,7 +8229,7 @@ case 878:
break;}
}
/* the action file gets copied in in place of this dollarsign */
-#line 542 "/usr/share/bison.simple"
+#line 543 "/usr/lib/bison.simple"
yyvsp -= yylen;
yyssp -= yylen;
@@ -4031,8 +4030,8 @@ static const short yycheck[] = { 4,
};
/* -*-C-*- Note some compilers choke on comments on `#line' lines. */
-#line 3 "/usr/share/bison.simple"
-/* This file comes from bison-1.27. */
+#line 3 "/usr/lib/bison.simple"
+/* This file comes from bison-1.28. */
/* Skeleton output parser for bison,
Copyright (C) 1984, 1989, 1990 Free Software Foundation, Inc.